==> kapow_1.5.10.orig.tar.bz2: kapow-1.5.10/translations/kapow_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicie la aplicación para el cambio de idioma surta efecto.</translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation>Informe de horas trabajadas</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Company:</source>
        <translation>Empresa:</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Dirección:</translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Teléfono:</translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation>Fax:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>Correo electrónico:</translation>
    </message>
    <message>
        <source>Website:</source>
        <translation>Página web:</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation>Anteponer símbolo de moneda</translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation>Tarifa por hora:</translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation>Tasa de impuesto:</translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation>Símbolo de moneda:</translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation>Información de contacto</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Datos</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Previsualización</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation>Página web (*.html *.htm)</translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation>iCalendar (*.ics)</translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation>CSV de Outlook (*.csv)</translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation>Exportar el informe</translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation>Ver los informes</translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation>Crear informe</translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation>Teléfono: %1</translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation>Fax: %1</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation>Subtotal</translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation>Impuestos</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n hora</numerusform>
            <numerusform>%n horas</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation>%L1 horas</translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation>Añadir sesión</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Fecha:</translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Inicio:</translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation>Fin:</translation>
    </message>
    <message>
        <source>Task:</source>
        <translation>Tarea:</translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation>Editar sesión</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Task</source>
        <translation>Tarea</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Diario</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Mensualmente</translation>
    </message>
    <message>
        <source>Report</source>
        <translation>Reporte</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation>&amp;Proyecto</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Mayús+N</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation>Ctrl+Mayús+Supr</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Sesión</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation>Ctrl+Supr</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Columnas</translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation>&amp;Totales decimales</translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation>&amp;Edición en la misma línea</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma de la aplicación…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Proyecto</translation>
    </message>
    <message>
        <source>Timer</source>
        <translation>Temporizador</translation>
    </message>
    <message>
        <source>Show all</source>
        <translation>Mostrar todo</translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation>Mostrar solo no facturados</translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation>Mostrar solo este año</translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation>Mostrar solo este mes</translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation>Mostrar solo esta semana</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado bajo la licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation>No se pudieron leer los datos del tiempo.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation>No se pudieron escribir los datos del tiempo.</translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation>Hay temporizadores en ejecución. ¿Quiere detenerlos y salir?</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation>Un programa para ayudar a rastrear tiempo consumido</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation>&amp;Crear el informe…</translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation>Ver los in&amp;formes</translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation>¿Quiere cancelar esta sesión?</translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation>Añadir un proyecto</translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation>Escriba el nombre del proyecto:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation>No se pudo crear la ubicación de datos del tiempo.</translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation>No se pudo mover la ubicación de datos del tiempo.</translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation>Ya existe un proyecto con ese nombre.</translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation>¿Quiere eliminar el proyecto seleccionado?</translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation>¿Quiere eliminar la sesión seleccionada?</translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>%n temporizador ejecutándose</numerusform>
            <numerusform>%n temporizadores ejecutándose</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation>Reloj de control Kapow</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation>El archivo temporal a usar.</translation>
    </message>
</context>
</TS>

==> kapow_1.6.2.orig.tar.bz2: kapow-1.6.2/translations/kapow_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicie la aplicación para el cambio de idioma surta efecto.</translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation>Informe de horas trabajadas</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Company:</source>
        <translation>Empresa:</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Dirección:</translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Teléfono:</translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation>Fax:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>Correo electrónico:</translation>
    </message>
    <message>
        <source>Website:</source>
        <translation>Página web:</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation>Anteponer símbolo de moneda</translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation>Tarifa por hora:</translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation>Tasa de impuesto:</translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation>Símbolo de moneda:</translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation>Información de contacto</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Datos</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Previsualización</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation>Página web (*.html *.htm)</translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation>iCalendar (*.ics)</translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation>CSV de Outlook (*.csv)</translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation>Exportar el informe</translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation>Ver los informes</translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation>Crear informe</translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation>Teléfono: %1</translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation>Fax: %1</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation>Subtotal</translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation>Impuestos</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Remove newest report?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n hora</numerusform>
            <numerusform>%n horas</numerusform>
            <numerusform>%n horas</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation>%L1 horas</translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation>Añadir sesión</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Fecha:</translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Inicio:</translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation>Fin:</translation>
    </message>
    <message>
        <source>Task:</source>
        <translation>Tarea:</translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation>Editar sesión</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Task</source>
        <translation>Tarea</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Diario</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Mensualmente</translation>
    </message>
    <message>
        <source>Report</source>
        <translation>Reporte</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimizar</translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation>&amp;Proyecto</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Mayús+N</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation>Ctrl+Mayús+Supr</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Sesión</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation>Ctrl+Supr</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Columnas</translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation>&amp;Totales decimales</translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation>&amp;Edición en la misma línea</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma de la aplicación…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Proyecto</translation>
    </message>
    <message>
        <source>Timer</source>
        <translation>Temporizador</translation>
    </message>
    <message>
        <source>Show all</source>
        <translation>Mostrar todo</translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation>Mostrar solo no facturados</translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation>Mostrar solo este año</translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation>Mostrar solo este mes</translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation>Mostrar solo esta semana</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado bajo la licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation>No se pudieron leer los datos del tiempo.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation>No se pudieron escribir los datos del tiempo.</translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation>Hay temporizadores en ejecución. ¿Quiere detenerlos y salir?</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation>Un programa para ayudar a rastrear tiempo consumido</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation>&amp;Crear el informe…</translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation>Ver los in&amp;formes</translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation>¿Quiere cancelar esta sesión?</translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation>Añadir un proyecto</translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation>Escriba el nombre del proyecto:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation>No se pudo crear la ubicación de datos del tiempo.</translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation>No se pudo mover la ubicación de datos del tiempo.</translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation>Ya existe un proyecto con ese nombre.</translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation>¿Quiere eliminar el proyecto seleccionado?</translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation>¿Quiere eliminar la sesión seleccionada?</translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>%n temporizador ejecutándose</numerusform>
            <numerusform>%n temporizadores ejecutándose</numerusform>
            <numerusform>%n temporizadores ejecutándose</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation>Reloj de control Kapow</translation>
    </message>
    <message>
        <source>&amp;Close to Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re&amp;move Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation>El archivo temporal a usar.</translation>
    </message>
</context>
</TS>
